@@ -17,5 +17,7 @@ from .PgsFile import StopWords
 from .PgsFile import EnPunctuation
 
 from .PgsFile import word_list
+from .PgsFile import clean_list
+from .PgsFile import yhd
 
 name = "PgsFile"
\ No newline at end of file
